@@ -22,6 +22,16 @@ def root():
     return app.send_static_file("index.htm")
 
 
+@app.after_request
+def add_header(response):
+    response.cache_control.max_age = 0
+    response.cache_control.no_cache = True
+    response.cache_control.no_store = True
+    response.cache_control.private = True
+    response.cache_control.public = False
+    return response
+
+
 api.add_resource(RequestList, "/requests")
 api.add_resource(Request, "/request/<req_id>")
 api.add_resource(RequestContentDown, "/request/<req_id>/down")
