@@ -15,31 +15,35 @@ async function refresh_resquests() {
         document.getElementById("cookies").innerHTML = 'select a request to view details';
         document.getElementById("body_sent").innerHTML = 'select a request to view details';
         document.getElementById("body_received").innerHTML = 'select a request to view details';
+        document.getElementById("exception").innerHTML = 'select a request to view details';
     };
     k7_id = global.k7;
 
     var tbody = table.getElementsByTagName("tbody")[0];
 
     for (const [request_id, request] of Object.entries(global.requests)) {
-        var elt = document.getElementById("request-" + request.id);
-        if (!elt) {
-            if (request.src) {
-                if (!document.getElementById("source-" + request.src.id)) {
-                    var rendered = Mustache.render(template_source, request.src);
+        if (request.to_refresh) {
+            var elt = document.getElementById("request-" + request.id);
+            if (!elt) {
+                if (request.src) {
+                    if (!document.getElementById("source-" + request.src.id)) {
+                        var rendered = Mustache.render(template_source, request.src);
+                        tbody.insertAdjacentHTML("beforeend", rendered);
+                    }
+                }
+
+                var rendered = Mustache.render(template_request, request);
+                if (request.src) {
+                    var last_row = document.querySelector("[data-source='" + request.src.id + "']:last-of-type");
+                    last_row.insertAdjacentHTML("afterend", rendered);
+                } else {
                     tbody.insertAdjacentHTML("beforeend", rendered);
                 }
-            }
-
-            var rendered = Mustache.render(template_request, request);
-            if (request.src) {
-                var last_row = document.querySelector("[data-source='" + request.src.id + "']:last-of-type");
-                last_row.insertAdjacentHTML("afterend", rendered);
             } else {
-                tbody.insertAdjacentHTML("beforeend", rendered);
-            }
-        } else {
-            elt.innerHTML = Mustache.render(template_request, request);
-        };
+                elt.innerHTML = Mustache.render(template_request, request);
+            };
+            request.to_refresh = false;
+        }
     };
 }
 
@@ -66,11 +70,17 @@ function show_request(request_id) {
 
     update_with_template("template_cookies", "cookies", data);
 
-    update_with_template("template_body", "body_sent", data.request);
+    var request = data.request ? data.request : {
+        "body": null
+    };
+    update_with_template("template_body", "body_sent", request);
 
-    if (data.response) {
-        update_with_template("template_body", "body_received", data.response);
-    }
+    var response = data.response ? data.response : {
+        "body": null
+    };
+    update_with_template("template_body", "body_received", response);
+
+    update_with_template("template_exception", "exception", data);
 }
 
 
